package inf1010.pusle.pathfinding.graph;

/**
 * An edge between two vertices.
 */
public class Edge {

    /** The vertices this edge connects. */
    private Vertex a, b;
    /** The distance between the two vertices.  */
    private double distance;

    /**
     * Creates an edge between two vertices.
     * It also adds the vertices as neighbours to each other.
     *
     * @param a The first vertex.
     * @param b The second vertex.
     * @param distance The distance between the two.
     * @see Vertex#addEdge(Edge, Vertex)
     */
    public Edge(Vertex a, Vertex b, double distance) {
        this.a = a;
        this.b = b;
        this.distance = distance;
        a.addEdge(this, b);
        b.addEdge(this, a);
    }

    /**
     * Gets the distance between the vertices.
     *
     * @return The distance between the two vertices.
     */
    public double getDistance() {
        return distance;
    }

    /**
     * Gets the first vertex.
     *
     * @return The first vertex.
     */
    public Vertex getA() {
        return a;
    }

    /**
     * Gets the second vertex.
     *
     * @return The second vertex.
     */
    public Vertex getB() {
        return b;
    }
}